@@ -148,12 +148,16 @@ class BaseGalileoLogger:
             elif attr == "Prob":
                 if config.task_type != TaskType.text_multi_label:
                     assert (
-                        len(arr.shape) == 2
-                    ), f"{attr} tensor must be 2D shape, but got shape {arr.shape}"
+                        arr.ndim == 2
+                    ), f"Probs/logits must have ndim=2, but got shape {arr.shape}"
                 else:
                     # Because probs in multi label may not have a clear shape (each
                     # task may have a different number of probabilities
                     arr = np.array(arr, dtype=object)
+                    assert arr.ndim > 1, (
+                        f"Probs/logits must have at least 2 dimensions, "
+                        f"they have {arr.ndim}"
+                    )
             elif attr == "Labels" and config.task_type == TaskType.text_multi_label:
                 arr = np.array(arr, dtype=object)
         return np.array(arr)
@@ -231,3 +235,13 @@ class BaseGalileoLogger:
     @classmethod
     def validate_split(cls, split: Union[str, Split]) -> str:
         return conform_split(split).value
+
+    @classmethod
+    def check_for_logging_failures(cls) -> None:
+        """When a threaded logging call fails, it sets the logger_config.exception
+
+        If that field is set, raise an exception here and stop the main process
+        """
+        # If a currently active thread crashed, check and raise a top level exception
+        if cls.logger_config.exception:
+            raise GalileoException(cls.logger_config.exception)
